Skip to content
KitploitKITPLOIT
ToolsExploitsBlog
Log in
Submit
ToolsExploitsBlog
Submit

Hacking, PenTest, and Cybersecurity Tools for Your Security Arsenal!

Kitploit is a directory of hacking, cybersecurity, and pentesting tools. Discover the latest project updates to find vulnerabilities, analyze systems, automate testing, and strengthen your security.

FeedsContactPrivacyยฉ 2026 Kitploit

Tool Directory

Categories

View all categories
Loading categories
ARTAXERXES โ€” Advanced Multi-Technology Stress Testing Framework Educational Cybersecurity Tool for High-Performance Network Testing | Kitploit
Tools/GitLabGitLab/toxy4ny/artaxerxes
Network SecurityPenetration TestingLearning & EducationRed TeamingLabs & Practice
GitLabtoxy4ny/artaxerxes

ARTAXERXES

Advanced Multi-Technology Stress Testing Framework Educational Cybersecurity Tool for High-Performance Network Testing

View Repository
932 months agoNot yet reviewed

Most Popular

View all โ†’

Discover the most used tools by our community.

Explore all tools

Browse our collection of tools

View all tools โ†’
Website
Share

ARTAXERXES ๐Ÿš€

Advanced Multi-Technology Stress Testing Framework
Educational Cybersecurity Tool for High-Performance Network Testing

License Platform CUDA Performance


๐Ÿ“‹ Table of Contents

  • ๐ŸŽฏ Overview
  • โšก Performance Comparison
  • ๐Ÿ› ๏ธ Technology Stack
  • ๐Ÿ“Š Architecture
  • ๐Ÿš€ Quick Start
  • โš™๏ธ Installation
  • ๐Ÿ’ก Usage Examples
  • ๐Ÿ”ง Advanced Configuration
  • ๐Ÿ“ˆ Benchmarks
  • ๐Ÿงช Laboratory Setup
  • ๐ŸŽ“ Educational Value
  • โš ๏ธ Legal Disclaimer

๐ŸŽฏ Overview

Xerxes-Ultimate represents the next generation of network stress testing tools, designed specifically for educational cybersecurity laboratories. Built upon the foundation of the original Xerxes DoS tool, this implementation leverages cutting-edge hardware acceleration technologies to achieve unprecedented performance levels while maintaining educational transparency.

Key Innovations

  • ๐ŸŽฎ Multi-GPU Acceleration: Harnesses up to 4x RTX 4070 Ti GPUs for payload generation
  • โšก Zero-Copy I/O: Eliminates CPU overhead with io_uring and GPUDirect
  • ๐ŸŒ User-Space Networking: Bypasses kernel bottlenecks with DPDK
  • ๐Ÿ”ฌ Kernel-Level Optimization: XDP/eBPF for ultimate performance
  • ๐Ÿง  Adaptive Intelligence: Machine learning-driven traffic patterns
  • ๐Ÿ“Š Real-Time Analytics: GPU-accelerated statistics computation

โšก Performance Comparison

Original Xerxes vs Xerxes-Ultimate

MetricOriginal XerxesXerxes-UltimateImprovement
Packets/Second~50,000 PPS60,000,000+ PPS๐Ÿš€ 1,200x faster
Bandwidth~100 Mbps60+ Gbps๐Ÿ”ฅ 600x increase
Concurrent Connections~1,0001,000,000+โšก 1,000x more
CPU Efficiency100% CPU usage<30% CPU usage๐Ÿ’ก 70% reduction
Memory UsageHigh fragmentationOptimized pools๐ŸŽฏ 90% efficient
Latency~1ms<100 nanosecondsโšก 10,000x faster

Performance Tiers

graph LR
    A[Original Xerxes<br/>50K PPS] --> B[BASIC Tier<br/>100K PPS<br/>2x improvement]
    B --> C[IO_URING Tier<br/>1M PPS<br/>20x improvement]
    C --> D[GPU Tier<br/>10M PPS<br/>200x improvement]
    D --> E[DPDK Tier<br/>30M PPS<br/>600x improvement]
    E --> F[ULTIMATE Tier<br/>60M+ PPS<br/>1,200x improvement]

๐Ÿ› ๏ธ Technology Stack

Core Technologies

๐ŸŽฎ CUDA Multi-GPU Acceleration

// Parallel payload generation across 4 GPUs
__global__ void generate_ultimate_payloads(char *payloads, int *sizes, 
                                          int payload_count, uint64_t seed) {
    int idx = blockIdx.x * blockDim.x + threadIdx.x;
    // 512 blocks ร— 1024 threads ร— 4 GPUs = 2,097,152 parallel generators
}

Benefits:

  • 2,000,000+ parallel payload generators
  • Cryptographically strong randomization
  • Zero CPU overhead for packet creation
  • 16GB total GPU memory for buffering

โšก io_uring Zero-Copy I/O

// Asynchronous submission queue
struct io_uring ring;
io_uring_queue_init(8192, &ring, IORING_SETUP_SQPOLL);

// Direct GPU->NIC transfer without CPU copies
io_uring_prep_send_zc(sqe, socket_fd, gpu_buffer, size, 0);

Benefits:

  • 400% I/O performance increase
  • Zero-copy GPU-to-NIC transfers
  • Eliminates context switching overhead
  • Scales to 100,000+ concurrent operations

๐ŸŒ DPDK User-Space Networking

// Bypass kernel network stack entirely
struct rte_mbuf *pkts[BURST_SIZE];
uint16_t nb_tx = rte_eth_tx_burst(port_id, queue_id, pkts, nb_pkts);

Benefits:

  • 500% packet processing improvement
  • Direct hardware access
  • Predictable latency (<100ns)
  • Line-rate 100GbE performance

๐Ÿ”ฌ XDP/eBPF Kernel Programming

SEC("xdp_ultimate")
int xdp_stress_program(struct xdp_md *ctx) {
    // Kernel-level packet manipulation
    return XDP_TX; // Retransmit at wire speed
}

Benefits:

  • 200% efficiency gain over user-space
  • Kernel-level packet generation
  • Programmable packet processing
  • Integration with hardware offload

๐Ÿ“Š Architecture

System Architecture Overview

graph TB
    subgraph "User Space"
        A[Control Thread] --> B[Thread Pool Manager]
        B --> C[GPU Generator Threads]
        B --> D[Network Transmit Threads]
        B --> E[Statistics Monitor]
    end
    
    subgraph "GPU Cluster"
        F[RTX 4070 Ti #1<br/>2,560 cores]
        G[RTX 4070 Ti #2<br/>2,560 cores]
        H[RTX 4070 Ti #3<br/>2,560 cores]
        I[RTX 4070 Ti #4<br/>2,560 cores]
        
        F --> J[GPU Memory Pool<br/>48GB Total]
        G --> J
        H --> J
        I --> J
    end
    
    subgraph "I/O Subsystem"
        K[io_uring Ring<br/>8192 entries]
        L[DPDK PMD Drivers]
        M[Zero-Copy Buffers]
    end
    
    subgraph "Kernel Space"
        N[XDP Hook]
        O[eBPF Programs]
        P[Network Interface]
    end
    
    C --> F
    C --> G
    C --> H 
    C --> I
    
    D --> K
    D --> L
    K --> M
    L --> M
    
    M --> N
    N --> O
    O --> P
    
    P --> Q[Target Network<br/>60+ Gbps]

Memory Architecture

graph LR
    subgraph "GPU Memory (16GB)"
        A[Payload Buffers<br/>8GB]
        B[Size Arrays<br/>2GB]
        C[Random States<br/>4GB]
        D[Working Space<br/>2GB]
    end
    
    subgraph "Host Memory (32GB)"
        E[Pinned Buffers<br/>16GB]
        F[Ring Buffers<br/>8GB]
        G[Connection Pool<br/>4GB]
        H[Statistics<br/>4GB]
    end
    
    subgraph "NIC Memory (1GB)"
        I[DMA Buffers<br/>512MB]
        J[Descriptor Rings<br/>256MB]
        K[Hardware Queues<br/>256MB]
    end
    
    A -.->|PCIe 4.0<br/>64 GB/s| E
    E -.->|Zero-Copy| F
    F -.->|DMA| I

๐Ÿš€ Quick Start

Prerequisites Check

# Run the capability detector
./scripts/check-capabilities.sh

Expected output:

๐Ÿ” Xerxes-Ultimate Capability Check
===================================
[โœ“] CUDA: 4 GPUs detected
[โœ“] DPDK: Compatible NIC detected  
[โœ“] io_uring: Kernel support available
[โœ“] XDP/eBPF: Root privileges available

Basic Launch

# Simple unlimited attack
./artaxerxes-ultimate 192.168.1.100 80

# Controlled burst testing
./artaxerxes-ultimate 192.168.1.100 80 10M_pps

# Bandwidth-limited testing  
./artaxerxes-ultimate 192.168.1.100 80 5Gbps

# Time-limited demonstration
./artaxerxes-ultimate 192.168.1.100 80 300s

โš™๏ธ Installation

Automatic Installation

# Clone repository
git clone https://gitlab.com/toxy4ny/ARTAXERXES.git
cd ARTAXERXES

# Run quick deployment script
sudo quick-deploy.sh

Manual Installation

1. Install Dependencies

Ubuntu/Debian:

# System packages
sudo apt-get update
sudo apt-get install -y build-essential cmake pkg-config \
    libnuma-dev libpcap-dev python3-pyelftools \
    libbpf-dev libelf-dev zlib1g-dev liburing-dev

# CUDA Toolkit (if not installed)
wget https://developer.download.nvidia.com/compute/cuda/12.3.0/local_installers/cuda_12.3.0_545.23.06_linux.run
sudo sh cuda_12.3.0_545.23.06_linux.run

# DPDK
wget http://fast.dpdk.org/rel/dpdk-22.11.1.tar.xz
tar xf dpdk-22.11.1.tar.xz
cd dpdk-22.11.1
meson setup build
cd build && ninja && sudo ninja install

CentOS/RHEL:

# Enable EPEL and PowerTools
sudo dnf install epel-release
sudo dnf config-manager --set-enabled powertools
Download Tool